==> ted-2.14.src.tar.gz: Ted-2.14/appUtil/utilTextAttribute.c <==
/************************************************************************/
/*									*/
/*  Font administration for a document.					*/
/*									*/
/************************************************************************/

#   include	"appUtilConfig.h"

#   include	<stdlib.h>
#   include	<stdio.h>
#   include	<string.h>

#   include	<appDebugon.h>

#   include	"utilPropMask.h"
#   include	"utilTextAttribute.h"

/************************************************************************/
/*									*/
/*  Set text attributes to a default value.				*/
/*									*/
/************************************************************************/

void utilInitTextAttribute(	TextAttribute *	ta	)
    {
    ta->taFontNumber= -1;
    ta->taFontSizeHalfPoints= 0;
    ta->taTextColorNumber= 0;
    ta->taFontIsBold= 0;
    ta->taFontIsSlanted= 0;
    ta->taTextIsUnderlined= 0;
    ta->taSuperSub= DOCfontREGULAR;
    ta->taSmallCaps= 0;
    ta->taHasStrikethrough= 0;
    ta->taCapitals= 0;
    }

/************************************************************************/
/*									*/
/*  Get text attribute difference mask.					*/
/*									*/
/************************************************************************/

void utilAttributeDifference(		PropertyMask *		pDoneMask,
					const TextAttribute *	taTo,
					const TextAttribute *	taFrom,
					const PropertyMask *	setMask )
    {
    PropertyMask	doneMask;

    if  ( ! setMask )
	{ XDEB(setMask); return;	}

    PROPmaskCLEAR( &doneMask );

    if  ( PROPmaskISSET( setMask, TApropFONTFAMILY )			&&
	  taTo->taFontNumber != taFrom->taFontNumber			)
	{ PROPmaskADD( &doneMask, TApropFONTFAMILY ); }

    if  ( PROPmaskISSET( setMask, TApropFONTSIZE )			&&
	  taTo->taFontSizeHalfPoints != taFrom->taFontSizeHalfPoints	)
	{ PROPmaskADD( &doneMask, TApropFONTSIZE ); }

    if  ( PROPmaskISSET( setMask, TApropTEXT_COLOR )			&&
	  taTo->taTextColorNumber != taFrom->taTextColorNumber		)
	{ PROPmaskADD( &doneMask, TApropTEXT_COLOR ); }

    if  ( PROPmaskISSET( setMask, TApropFONTBOLD )			&&
	  taTo->taFontIsBold != taFrom->taFontIsBold			)
	{ PROPmaskADD( &doneMask, TApropFONTBOLD ); }

    if  ( PROPmaskISSET( setMask, TApropFONTSLANTED )			&&
	  taTo->taFontIsSlanted != taFrom->taFontIsSlanted		)
	{ PROPmaskADD( &doneMask, TApropFONTSLANTED ); }

    if  ( PROPmaskISSET( setMask, TApropTEXTUNDERLINED )		&&
	  taTo->taTextIsUnderlined != taFrom->taTextIsUnderlined	)
	{ PROPmaskADD( &doneMask, TApropTEXTUNDERLINED ); }

    if  ( PROPmaskISSET( setMask, TApropSUPERSUB )			&&
	  taTo->taSuperSub != taFrom->taSuperSub			)
	{ PROPmaskADD( &doneMask, TApropSUPERSUB ); }

    if  ( PROPmaskISSET( setMask, TApropSMALLCAPS )			&&
	  taTo->taSmallCaps != taFrom->taSmallCaps			)
	{ PROPmaskADD( &doneMask, TApropSMALLCAPS ); }

    if  ( PROPmaskISSET( setMask, TApropCAPITALS )			&&
	  taTo->taCapitals != taFrom->taCapitals			)
	{ PROPmaskADD( &doneMask, TApropCAPITALS ); }

    if  ( PROPmaskISSET( setMask, TApropSTRIKETHROUGH )			&&
	  taTo->taHasStrikethrough != taFrom->taHasStrikethrough	)
	{ PROPmaskADD( &doneMask, TApropSTRIKETHROUGH ); }

    *pDoneMask= doneMask;
    return;
    }

void utilUpdateTextAttribute(		PropertyMask *		pDoneMask,
					TextAttribute *		taTo,
					const TextAttribute *	taFrom,
					const PropertyMask *	setMask )
    {
    PropertyMask	doneMask= *pDoneMask;

    if  ( PROPmaskISSET( setMask, TApropFONTFAMILY )			&&
	  taTo->taFontNumber != taFrom->taFontNumber			)
	{
	taTo->taFontNumber= taFrom->taFontNumber;
	PROPmaskADD( &doneMask, TApropFONTFAMILY );
	}

    if  ( PROPmaskISSET( setMask, TApropFONTSIZE )			&&
	  taTo->taFontSizeHalfPoints != taFrom->taFontSizeHalfPoints	)
	{
	taTo->taFontSizeHalfPoints= taFrom->taFontSizeHalfPoints;
	PROPmaskADD( &doneMask, TApropFONTSIZE );
	}

    if  ( PROPmaskISSET( setMask, TApropTEXT_COLOR )			&&
	  taTo->taTextColorNumber != taFrom->taTextColorNumber		)
	{
	taTo->taTextColorNumber= taFrom->taTextColorNumber;
	PROPmaskADD( &doneMask, TApropTEXT_COLOR );
	}

    if  ( PROPmaskISSET( setMask, TApropFONTBOLD )			&&
	  taTo->taFontIsBold != taFrom->taFontIsBold			)
	{
	taTo->taFontIsBold= taFrom->taFontIsBold;	
	PROPmaskADD( &doneMask, TApropFONTBOLD );
	}

    if  ( PROPmaskISSET( setMask, TApropFONTSLANTED )			&&
	  taTo->taFontIsSlanted != taFrom->taFontIsSlanted		)
	{
	taTo->taFontIsSlanted= taFrom->taFontIsSlanted;
	PROPmaskADD( &doneMask, TApropFONTSLANTED );
	}

    if  ( PROPmaskISSET( setMask, TApropTEXTUNDERLINED )		&&
	  taTo->taTextIsUnderlined != taFrom->taTextIsUnderlined	)
	{
	taTo->taTextIsUnderlined= taFrom->taTextIsUnderlined;
	PROPmaskADD( &doneMask, TApropTEXTUNDERLINED );
	}

    if  ( PROPmaskISSET( setMask, TApropSUPERSUB )			&&
	  taTo->taSuperSub != taFrom->taSuperSub			)
	{
	taTo->taSuperSub= taFrom->taSuperSub;
	PROPmaskADD( &doneMask, TApropSUPERSUB );
	}

    if  ( PROPmaskISSET( setMask, TApropSMALLCAPS )			&&
	  taTo->taSmallCaps != taFrom->taSmallCaps			)
	{
	taTo->taSmallCaps= taFrom->taSmallCaps;
	PROPmaskADD( &doneMask, TApropSMALLCAPS );
	}

    if  ( PROPmaskISSET( setMask, TApropCAPITALS )			&&
	  taTo->taCapitals != taFrom->taCapitals			)
	{
	taTo->taCapitals= taFrom->taCapitals;
	PROPmaskADD( &doneMask, TApropCAPITALS );
	}

    if  ( PROPmaskISSET( setMask, TApropSTRIKETHROUGH )			&&
	  taTo->taHasStrikethrough != taFrom->taHasStrikethrough	)
	{
	taTo->taHasStrikethrough= taFrom->taHasStrikethrough;
	PROPmaskADD( &doneMask, TApropSTRIKETHROUGH );
	}

    *pDoneMask= doneMask;
    return;
    }

==> ted-2.21.src.tar.gz: Ted-2.21/appUtil/utilTextAttribute.c <==
/************************************************************************/
/*									*/
/*  Font administration for a document.					*/
/*									*/
/************************************************************************/

#   include	"appUtilConfig.h"

#   include	<stdlib.h>
#   include	<stdio.h>
#   include	<string.h>

#   include	<appDebugon.h>

#   include	"utilPropMask.h"
#   include	"utilTextAttribute.h"

/************************************************************************/
/*									*/
/*  Set text attributes to a default value.				*/
/*									*/
/************************************************************************/

void utilInitTextAttribute(	TextAttribute *	ta	)
    {
    ta->taFontNumber= -1;
    ta->taFontSizeHalfPoints= 0;
    ta->taTextColorNumber= 0;
    ta->taBorderNumber= 0;
    ta->taShadingNumber= 0;
    ta->taTextStyleNumber= 0;
    ta->taFontIsBold= 0;
    ta->taFontIsSlanted= 0;
    ta->taTextIsUnderlined= 0;
    ta->taSuperSub= DOCfontREGULAR;
    ta->taSmallCaps= 0;
    ta->taHasStrikethrough= 0;
    ta->taCapitals= 0;
    }

/************************************************************************/
/*									*/
/*  Get text attribute difference mask.					*/
/*									*/
/************************************************************************/

void utilAttributeDifference(		PropertyMask *		pDoneMask,
					const TextAttribute *	taTo,
					const TextAttribute *	taFrom,
					const PropertyMask *	setMask )
    {
    PropertyMask	doneMask;

    if  ( ! setMask )
	{ XDEB(setMask); return;	}

    utilPropMaskClear( &doneMask );

    if  ( PROPmaskISSET( setMask, TApropDOC_FONT_NUMBER )		&&
	  taTo->taFontNumber != taFrom->taFontNumber			)
	{ PROPmaskADD( &doneMask, TApropDOC_FONT_NUMBER ); }

    if  ( PROPmaskISSET( setMask, TApropFONTSIZE )			&&
	  taTo->taFontSizeHalfPoints != taFrom->taFontSizeHalfPoints	)
	{ PROPmaskADD( &doneMask, TApropFONTSIZE ); }

    if  ( PROPmaskISSET( setMask, TApropTEXT_COLOR )			&&
	  taTo->taTextColorNumber != taFrom->taTextColorNumber		)
	{ PROPmaskADD( &doneMask, TApropTEXT_COLOR ); }

    if  ( PROPmaskISSET( setMask, TApropBORDER )			&&
	  taTo->taBorderNumber != taFrom->taBorderNumber		)
	{ PROPmaskADD( &doneMask, TApropBORDER ); }

    if  ( PROPmaskISSET( setMask, TApropSHADING )			&&
	  taTo->taShadingNumber != taFrom->taShadingNumber		)
	{ PROPmaskADD( &doneMask, TApropSHADING ); }

    if  ( PROPmaskISSET( setMask, TApropTEXT_STYLE )			&&
	  taTo->taTextStyleNumber != taFrom->taTextStyleNumber		)
	{ PROPmaskADD( &doneMask, TApropTEXT_STYLE ); }

    if  ( PROPmaskISSET( setMask, TApropFONTBOLD )			&&
	  taTo->taFontIsBold != taFrom->taFontIsBold			)
	{ PROPmaskADD( &doneMask, TApropFONTBOLD ); }

    if  ( PROPmaskISSET( setMask, TApropFONTSLANTED )			&&
	  taTo->taFontIsSlanted != taFrom->taFontIsSlanted		)
	{ PROPmaskADD( &doneMask, TApropFONTSLANTED ); }

    if  ( PROPmaskISSET( setMask, TApropTEXTUNDERLINED )		&&
	  taTo->taTextIsUnderlined != taFrom->taTextIsUnderlined	)
	{ PROPmaskADD( &doneMask, TApropTEXTUNDERLINED ); }

    if  ( PROPmaskISSET( setMask, TApropSUPERSUB )			&&
	  taTo->taSuperSub != taFrom->taSuperSub			)
	{ PROPmaskADD( &doneMask, TApropSUPERSUB ); }

    if  ( PROPmaskISSET( setMask, TApropSMALLCAPS )			&&
	  taTo->taSmallCaps != taFrom->taSmallCaps			)
	{ PROPmaskADD( &doneMask, TApropSMALLCAPS ); }

    if  ( PROPmaskISSET( setMask, TApropCAPITALS )			&&
	  taTo->taCapitals != taFrom->taCapitals			)
	{ PROPmaskADD( &doneMask, TApropCAPITALS ); }

    if  ( PROPmaskISSET( setMask, TApropSTRIKETHROUGH )			&&
	  taTo->taHasStrikethrough != taFrom->taHasStrikethrough	)
	{ PROPmaskADD( &doneMask, TApropSTRIKETHROUGH ); }

    *pDoneMask= doneMask;
    return;
    }

void utilUpdateTextAttribute(		PropertyMask *		pDoneMask,
					TextAttribute *		taTo,
					const TextAttribute *	taFrom,
					const PropertyMask *	setMask )
    {
    PropertyMask	doneMask= *pDoneMask;

    if  ( PROPmaskISSET( setMask, TApropDOC_FONT_NUMBER )		&&
	  taTo->taFontNumber != taFrom->taFontNumber			)
	{
	taTo->taFontNumber= taFrom->taFontNumber;
	PROPmaskADD( &doneMask, TApropDOC_FONT_NUMBER );
	}

    if  ( PROPmaskISSET( setMask, TApropFONTSIZE )			&&
	  taTo->taFontSizeHalfPoints != taFrom->taFontSizeHalfPoints	)
	{
	taTo->taFontSizeHalfPoints= taFrom->taFontSizeHalfPoints;
	PROPmaskADD( &doneMask, TApropFONTSIZE );
	}

    if  ( PROPmaskISSET( setMask, TApropTEXT_COLOR )			&&
	  taTo->taTextColorNumber != taFrom->taTextColorNumber		)
	{
	taTo->taTextColorNumber= taFrom->taTextColorNumber;
	PROPmaskADD( &doneMask, TApropTEXT_COLOR );
	}

    if  ( PROPmaskISSET( setMask, TApropBORDER )			&&
	  taTo->taBorderNumber != taFrom->taBorderNumber		)
	{
	taTo->taBorderNumber= taFrom->taBorderNumber;
	PROPmaskADD( &doneMask, TApropBORDER );
	}

    if  ( PROPmaskISSET( setMask, TApropSHADING )			&&
	  taTo->taShadingNumber != taFrom->taShadingNumber		)
	{
	taTo->taShadingNumber= taFrom->taShadingNumber;
	PROPmaskADD( &doneMask, TApropSHADING );
	}

    if  ( PROPmaskISSET( setMask, TApropTEXT_STYLE )			&&
	  taTo->taTextStyleNumber != taFrom->taTextStyleNumber		)
	{
	taTo->taTextStyleNumber= taFrom->taTextStyleNumber;
	PROPmaskADD( &doneMask, TApropTEXT_STYLE );
	}

    if  ( PROPmaskISSET( setMask, TApropFONTBOLD )			&&
	  taTo->taFontIsBold != taFrom->taFontIsBold			)
	{
	taTo->taFontIsBold= taFrom->taFontIsBold;	
	PROPmaskADD( &doneMask, TApropFONTBOLD );
	}

    if  ( PROPmaskISSET( setMask, TApropFONTSLANTED )			&&
	  taTo->taFontIsSlanted != taFrom->taFontIsSlanted		)
	{
	taTo->taFontIsSlanted= taFrom->taFontIsSlanted;
	PROPmaskADD( &doneMask, TApropFONTSLANTED );
	}

    if  ( PROPmaskISSET( setMask, TApropTEXTUNDERLINED )		&&
	  taTo->taTextIsUnderlined != taFrom->taTextIsUnderlined	)
	{
	taTo->taTextIsUnderlined= taFrom->taTextIsUnderlined;
	PROPmaskADD( &doneMask, TApropTEXTUNDERLINED );
	}

    if  ( PROPmaskISSET( setMask, TApropSUPERSUB )			&&
	  taTo->taSuperSub != taFrom->taSuperSub			)
	{
	taTo->taSuperSub= taFrom->taSuperSub;
	PROPmaskADD( &doneMask, TApropSUPERSUB );
	}

    if  ( PROPmaskISSET( setMask, TApropSMALLCAPS )			&&
	  taTo->taSmallCaps != taFrom->taSmallCaps			)
	{
	taTo->taSmallCaps= taFrom->taSmallCaps;
	PROPmaskADD( &doneMask, TApropSMALLCAPS );
	}

    if  ( PROPmaskISSET( setMask, TApropCAPITALS )			&&
	  taTo->taCapitals != taFrom->taCapitals			)
	{
	taTo->taCapitals= taFrom->taCapitals;
	PROPmaskADD( &doneMask, TApropCAPITALS );
	}

    if  ( PROPmaskISSET( setMask, TApropSTRIKETHROUGH )			&&
	  taTo->taHasStrikethrough != taFrom->taHasStrikethrough	)
	{
	taTo->taHasStrikethrough= taFrom->taHasStrikethrough;
	PROPmaskADD( &doneMask, TApropSTRIKETHROUGH );
	}

    *pDoneMask= doneMask;
    return;
    }

int utilSetTextProperty(		TextAttribute *		ta,
					int			prop,
					int			arg )
    {
    switch( prop )
	{
	case TApropDOC_FONT_NUMBER:
	    ta->taFontNumber= arg;
	    break;

	case TApropFONTSIZE:
	    ta->taFontSizeHalfPoints= arg;
	    break;

	case TApropTEXT_STYLE:
	    ta->taTextStyleNumber= arg;
	    break;

	case TApropTEXT_COLOR:
	    ta->taTextColorNumber= arg;
	    break;

	case TApropBORDER:
	    ta->taBorderNumber= arg;
	    break;

	case TApropFONTBOLD:
	    ta->taFontIsBold= arg != 0;
	    break;

	case TApropFONTSLANTED:
	    ta->taFontIsSlanted= arg != 0;
	    break;

	case TApropTEXTUNDERLINED:
	    ta->taTextIsUnderlined= arg != 0;
	    break;

	case TApropSUPERSUB:
	    ta->taSuperSub= arg;
	    break;

	case TApropSMALLCAPS:
	    ta->taSmallCaps= arg != 0;
	    break;

	case TApropCAPITALS:
	    ta->taCapitals= arg != 0;
	    break;

	case TApropSTRIKETHROUGH:
	    ta->taHasStrikethrough= arg != 0;
	    break;

	default:
	    LDEB(prop); return -1;
	}

    return 0;
    }

int utilGetTextProperty(		const TextAttribute *	ta,
					int			prop )
    {
    switch( prop )
	{
	case TApropDOC_FONT_NUMBER:
	    return ta->taFontNumber;

	case TApropFONTSIZE:
	    return ta->taFontSizeHalfPoints;

	case TApropFONTBOLD:
	    return ta->taFontIsBold;

	case TApropFONTSLANTED:
	    return ta->taFontIsSlanted;

	case TApropTEXTUNDERLINED:
	    return ta->taTextIsUnderlined;

	case TApropSUPERSUB:
	    return ta->taSuperSub;

	case TApropSMALLCAPS:
	    return ta->taSmallCaps;

	case TApropCAPITALS:
	    return ta->taCapitals;

	case TApropSTRIKETHROUGH:
	    return ta->taHasStrikethrough;

	case TApropTEXT_COLOR:
	    return ta->taTextColorNumber;

	case TApropBORDER:
	    return ta->taBorderNumber;

	case TApropSHADING:
	    return ta->taShadingNumber;

	case TApropTEXT_STYLE:
	    return ta->taTextStyleNumber;

	default:
	    LDEB(prop); return -1;
	}
    }
